import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import * as React from "react";
import PropTypes from "prop-types";
import { useMeasure } from "./Hooks/use-measure";
import cx from "classnames";
import { useTheme } from "./Theme/Providers";
//在一行内部的空间分配比例 %：
const flexClPp = [100, 50, 33.333, 25, 20];
//缺省breaks ： <LineColumn column={2} breaks={[288, 520]}
//可以安排几个列
const defaultBreakOf = [
    [330],
    [320, 840],
    [314, 628, 942],
    [292, 584, 876, 1168],
    [240, 480, 720, 960, 1200],
];
/**
 * 布局组件：最多5列的。
 * 1，2列，3列，4列，5列。
 * 父辈窗口屏幕宽度就算再大，也是只安排2 或3 或4 或5 个列的，布局思路。
 为了整齐对齐的需要；
 * 特别注意！！ LineColumn底下的子组件第一个div或者<tag>的样式请不要使用padding和margin的设置px; 就算要设置所有儿子也必须保持一致。
 * 用InputLineL来代替InputGroup因为其内部section默认padding:48px 20px所以会导致布局宽度分配不一致。
 * fitable注入给儿子组件报错问题：儿子不要是不可接受fitable参数的原生Tag;
 * 实际经验 测试调整column={5} breaks={[170,290,390,490,750]}取值，根据目标编辑宽度以及实际的DIV容器宽度判定。
 * 【有问题的是LineColumn】没办法穿透<>和<React.Fragment>俩个空白语法标签；儿子不能放在这两个底下。可以中间套一个<div>封装。
 */
export const LineColumn = ({ column = 2, children, breaks = defaultBreakOf[column - 1], nowrap, ...other }) => {
    const theme = useTheme();
    const reflc = React.useRef(null);
    // const width=reflc?.current?.getBoundingClientRect()?.width || 0;        //假如useMeasure(reflc)?.width!;打印有问题；宽度感知落后。
    const width = useMeasure(reflc.current ? reflc : null)?.width || 0;
    //最适合搞几个列。
    const [suitableCls, setSuitableCls] = React.useState(2);
    // const printing = useMedia('print');     //React.cloneElement(传递的printing都是:====false的。打印不会看到true;
    //【为了打印正常不能改掉的】@ @注意！ useLayoutEffect； 假如改成 useEffect无法正常打印预览列{suitableCls}宽{width}的连两个数字前面哪个不对了!。useLayoutEffect更新彻底，useEffect会需要两次刷新啊。
    React.useLayoutEffect(() => {
        let i = 0;
        for (; i < column; i++)
            if (width < breaks[i])
                break;
        setSuitableCls(i < 1 ? 1 : i);
    }, [width, column, setSuitableCls, breaks]);
    //【不能用】useEffect(=> {setSuitableCls(i<1? 1:i);}） 分步走的会 有问题：延迟时机，打印情形就出问题；显示器显示没毛病。
    // const {suitableCls, fitable}= React.useMemo( () => {
    //     let i=0;
    //     for(;i<column;i++)
    //         if(width < breaks[i])   break;
    //     // setSuitableCls(i<1? 1:i);
    //     let suitableCls=i<1? 1:i;
    //     // setFitable( i>0 );
    //     let fitable= i>0;
    //     if(width<=0)  return {suitableCls: 2, fitable: true};
    //     return {suitableCls, fitable};
    // }, [width, reflc.current, column, breaks ]);
    if (column > 5 || column < 1)
        throw new Error("number of columns must >=1 and <=5");
    const itemCount = React.Children.count(children);
    const lineSum = Math.ceil(itemCount / suitableCls);
    //【打印的情形：printing没办法传递最新取自给儿子，还是旧的printing取值】  React.useMemo( ()也不行啊。
    const items = React.Children.map(children, (item, index) => {
        return React.cloneElement(item, {
            className: cx(['LineColumn-item',
                index === itemCount - 1 ? 'Litem-last' : ''
            ]),
            style: { flex: `1 1 ${flexClPp[suitableCls - 1]}%`,
                marginTop: theme.spaces.xs,
                //这里 不能用[theme.mediaQueries.md]: {}
                "@media (minWidth: 629px)": {
                    marginTop: theme.spaces.sm,
                }
            },
        });
    });
    const fakeSons = lineSum * suitableCls - itemCount;
    //必须加一层div{{ position: 'relative' }}，后面给出的父辈Div宽度width才对的。
    return (_jsxs("div", { ref: reflc, style: { display: 'flex', position: 'relative', justifyContent: 'center',
            flexWrap: nowrap ? 'nowrap' : 'wrap', width: '-webkit-fill-available'
        }, ...other, children: [items, fakeSons > 0 && (new Array(fakeSons)).fill(null).map((each, clm) => {
                return _jsx("div", { css: { flex: `1 1 ${flexClPp[suitableCls - 1]}%`,
                        marginTop: theme.spaces.xs,
                        [theme.mediaQueries.md]: {
                            marginTop: theme.spaces.sm,
                        }
                    } }, clm);
            })] }));
};
LineColumn.displayName = "LineColumn";
LineColumn.propTypes = {
    children: PropTypes.node
};
//# sourceMappingURL=LineColumn.js.map