import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { Text } from "./Text";
import PropTypes from "prop-types";
import { MenuLabel } from "./Menu";
import { useTheme } from "./Theme/Providers";
import { noOp } from "./misc/noop";
import { safeBind } from "./Hooks/compose-bind";
// import {ElementType} from "react";
import { usePressable } from "./Hooks/pressable-hook";
export const List = ({ children, ...other }) => {
    return _jsx("nav", { ...other, children: children });
};
List.propTypes = {
    children: PropTypes.node
};
/**准备替换掉旧的 ListItem, #简易版本。没有用旧的"react-gesture-responder"包！
 * [考虑] 没必要提供拉拽的同时取消当前点击到的ListItem避免触发。 而触摸屏本就没这样问题。
 * 列表底下的各个项目：可以插入大类分类层次 ListSection。
 *    <ListSection >
 <ListItem  />
 </ListSection>
 <Divider muted />
 若通过<ListItemcss={{padding: "0.3rem 0.3rem",}}的，在这里实际由...other接受了外部样式注入修改。
 [准备移除 ] useTouchable ？
 #问题：轮播台电脑模式拉动触发，同时触发点击。旧版本:会存在等待进一步Move消息可能会取消的步骤。
 * */
export const ListItem = ({ primary, secondary, contentBefore, interactive = true, children, wrap = true, contentAfter, onPress = noOp, component: Component = "div", noBind = false, terminateOnScroll = false, delay = 30, secondStyle, ...other }) => {
    const interactiveProps = interactive
        ? {
            role: "button",
            tabIndex: 0
        }
        : {};
    const isLink = other.to || other.href;
    //这个{bind｛ref｝}给了哪一个Div;那么就针对哪一个DIV的矩形框框才能触发函数 onPress()。从z-index维度上看上一层的更小的div优先。
    const { bind, hover, active } = usePressable({
        onPress,
        behavior: isLink ? "link" : "button"
    });
    const theme = useTheme();
    //console.log("ListItemdl=",delay, "terminateOnScroll=",terminateOnScroll);
    return (_jsx(Component, { className: "ListItem", css: [
            {
                display: "block",
                textDecoration: "none",
                outline: "none",
                padding: theme.spaces.sm,
                background: "transparent",
                WebkitTapHighlightColor: "transparent",
                transition: "background 0.07s ease",
                [theme.mediaQueries.lg]: {
                    paddingLeft: theme.spaces.lg,
                    paddingRight: theme.spaces.lg
                },
                ":last-child": {
                    borderBottom: "none"
                }
            },
        ], ...other, children: _jsxs("div", { className: "ListItem__container", css: { display: "flex", alignItems: "center" }, children: [contentBefore && (_jsx("div", { className: "ListItem__content-before", css: { marginRight: theme.spaces.md }, children: contentBefore })), _jsxs("div", { className: "ListItem__content", css: [
                        {
                            flex: 1,
                            overflow: "hidden",
                        },
                        interactive && {
                            cursor: "pointer",
                            ":focus": {
                                boxShadow: `inset 0 0 3px ${theme.colors.text.selected}`
                            },
                            ":focus:not([data-focus-visible-added])": {
                                boxShadow: "none"
                            }
                        },
                        interactive &&
                            hover && {
                            background: theme.colors.background.tint1
                        },
                        interactive &&
                            active && {
                            background: theme.colors.background.tint2
                        }
                    ], ...interactiveProps, ...safeBind(!noBind && interactive ? bind : {}), children: [_jsx(Text, { className: "ListItem__primary", wrap: wrap, variant: "body", css: { display: "block", fontWeight: 500 }, children: primary }), secondary && (_jsx(Text, { className: "ListItem__secondary", wrap: wrap, css: [
                                {
                                    display: "block",
                                    fontSize: theme.fontSizes[0],
                                },
                                secondStyle
                            ], variant: "body", muted: true, children: secondary })), children] }), contentAfter && (_jsx("div", { className: "ListItem__content-after", css: { flex: "0 0 auto" }, children: contentAfter }))] }) }));
};
export const ListSection = ({ title, children, sticky = true, ...other }) => {
    const theme = useTheme();
    const bg = theme.colors.background.layer;
    return (_jsxs("div", { css: {
            ":first-child > *": {
                borderTop: "none"
            }
        }, children: [_jsx(MenuLabel, { css: {
                    position: sticky ? "sticky" : "static",
                    top: 0,
                    backgroundColor: sticky ? bg : "transparent",
                    padding: theme.spaces.sm,
                    paddingLeft: theme.spaces.md,
                    marginTop: theme.spaces.md,
                    [theme.mediaQueries.lg]: {
                        paddingLeft: theme.spaces.lg,
                        paddingRight: theme.spaces.lg
                    }
                }, ...other, children: title }), children] }));
};
ListSection.propTypes = {
    title: PropTypes.string.isRequired,
    sticky: PropTypes.bool,
    children: PropTypes.node
};
/**代替ListItem,实现更为自由样式, 类比Table组件的每一行TableRow功能。
 <ListFlexRow css={{
        padding: "0.3rem 0.3rem",
        alignItems: "center",
        display: "flex",
        justifyContent: "space-between",
        "& em": {
        fontStyle: "normal",
            color: theme.colors.text.selected
        },
        "& > *": {
            flex: 1,
                overflow: "hidden"
        }
    }}
 > </ListFlexRow>
 若通过<ListFlexRow css={{padding: "0.3rem 0.3rem",}}的，在这里实际由...other接受了外部样式注入修改。
 * */
export const ListFlexRow = ({ primary, secondary, contentBefore, interactive = true, children, wrap = true, contentAfter, onPress = noOp, component: Component = "div", noBind = false, terminateOnScroll = false, delay = 30, secondStyle, ...other }) => {
    const interactiveProps = interactive
        ? {
            role: "button",
            tabIndex: 0
        }
        : {};
    const isLink = other.to || other.href;
    const { bind, hover, active } = usePressable({
        onPress,
        behavior: isLink ? "link" : "button"
    });
    const theme = useTheme();
    return (_jsxs(Component, { className: "ListFlexRow", css: [
            {
                display: 'flex',
                flexDirection: 'row',
                alignContent: 'center',
                justifyContent: 'space-between',
                alignItems: 'center',
                flexWrap: 'nowrap',
                textDecoration: "none",
                outline: "none",
                padding: "0.15rem 0.2rem",
                background: "transparent",
                WebkitTapHighlightColor: "transparent",
                transition: "background 0.07s ease",
                [theme.mediaQueries.md]: {
                    padding: `0.15rem 0.4rem`,
                },
                [theme.mediaQueries.xl]: {
                    padding: `${theme.spaces.xs} 1rem`,
                },
                ":last-child": {
                    borderBottom: "none"
                }
            },
            interactive && {
                cursor: "pointer",
                ":focus": {
                    boxShadow: `inset 0 0 3px ${theme.colors.text.selected}`
                },
                ":focus:not([data-focus-visible-added])": {
                    boxShadow: "none"
                }
            },
            interactive &&
                hover && {
                background: theme.colors.background.tint1
            },
            interactive &&
                active && {
                background: theme.colors.background.tint2
            }
        ], ...interactiveProps, ...safeBind(!noBind && interactive ? bind : {}, other), children: [contentBefore && (_jsx("div", { className: "ListFlexRow-before", css: { marginRight: theme.spaces.md }, children: contentBefore })), _jsxs("div", { className: "ListFlexRow_content", css: {
                    display: 'flex',
                    flexDirection: 'row',
                    alignContent: 'center',
                    justifyContent: 'space-between',
                    alignItems: 'center',
                    flexWrap: 'wrap',
                    flex: 1,
                }, children: [primary && (_jsx(Text, { className: "ListFlexRow_primary", wrap: wrap, variant: "body", css: { fontWeight: 500 }, children: primary })), secondary && (_jsx(Text, { className: "ListFlexRow_secondary", wrap: wrap, css: [
                            {
                                fontSize: theme.fontSizes[0],
                            },
                            secondStyle
                        ], variant: "body", muted: true, children: secondary })), children] }), contentAfter && (_jsx("div", { className: "ListFlexRow-after", css: { flex: "0 0 auto" }, children: contentAfter }))] }));
};
//# sourceMappingURL=List.js.map